Welcome to then's documentation!
======================================
When "something" THEN send email/sms/telegram/event/execute... or Whatever 

To **install** then, run this command in your terminal:

.. code-block:: console

    $ pip install amazon_dash


Contents
--------

.. toctree::
   :maxdepth: 3

   readme
   installation
   usage
   troubleshooting
   modules
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
